function [ mue_t, mue_b, error_new ] = calc_mue(H, m, p, mue, error, err_par, eps_par)

% This is an internal function used by the function 
% opt_measurements_mat

% 
% You are very welcome to use this code. For this, clearly acknowledge 
% the source of this code, and cite the paper that describes the algorithm:
% M. Mordechay and Y. Y. Schechner, "Matrix optimization for poisson compressed
% sensing," in Proceedings of IEEE GlobalSIP, December 2014, pp.684-688.
%
% (c) Copyright Moran Mordechay 2014. The matlab code is available for 
% non-commercial use and exploration.  For commercial use contact the
% author. The author is not liable for any damages or loss that might be 
% caused by use or connection to this code. 



d = eig(H);
vec = real(d);
pos = vec > 0;
vec(pos) = 0;
vec(1:m-p) = d(1:m-p);
error_new = norm(vec);
mue_E = sqrt((m - p)/(m * p - p));
eps_old = mue - mue_E;

if (error_new < err_par * error)
    eps_new = eps_par * eps_old;
    mue_t = mue_E + eps_new;
    mue_b = mue_E - eps_new;
    error_new = error;
else
    mue_t = mue;
    mue_b = mue_E - eps_old;
    error_new = error;
end

if (error == 0)
    error_new = norm(vec);
end

end

