function [ x ] = orthogonal_projection_on_delta_n( y )

% This is an internal function used by the function fista. 
% 
% You are very welcome to use this code. For this, clearly acknowledge 
% the source of this code, and cite the paper that describes the algorithm:
% M. Mordechay and Y. Y. Schechner, "Matrix optimization for poisson compressed
% sensing," in Proceedings of IEEE GlobalSIP, December 2014, pp.684-688.
%
% (c) Copyright Moran Mordechay 2014. The matlab code is available for 
% non-commercial use and exploration.  For commercial use contact the
% author. The author is not liable for any damages or loss that might be 
% caused by use or connection to this code. 


n = numel(y);
a = min(y) - 1/n;
b = max(y);
lambda = b;
f = -1;

while (abs(f)>10^-5)
    if (f>0)
        a = lambda;
    else
        b = lambda;
    end
    lambda = (a+b)/2;
    temp = y - lambda;
    negs = temp < 0;
    temp(negs) = 0;
    f = sum(temp) - 1;
end

x = y - lambda;
negs = x < 0;
x(negs) = 0;

end

